package com.ruoyi.powerdistribution.mapper;

import java.util.List;
import com.ruoyi.powerdistribution.domain.PdmScoreRankCompany;

/**
 * 单位积分排名Mapper接口
 *
 * @author ruoyi
 * @date 2024-12-09
 */
public interface PdmScoreRankCompanyMapper
{
    /**
     * 查询单位积分排名
     *
     * @param id 单位积分排名主键
     * @return 单位积分排名
     */
    public PdmScoreRankCompany selectPdmScoreRankCompanyById(Long id);

    /**
     * 查询单位积分排名列表
     *
     * @param pdmScoreRankCompany 单位积分排名
     * @return 单位积分排名集合
     */
    public List<PdmScoreRankCompany> selectPdmScoreRankCompanyList(PdmScoreRankCompany pdmScoreRankCompany);

    /**
     * 新增单位积分排名
     *
     * @param pdmScoreRankCompany 单位积分排名
     * @return 结果
     */
    public int insertPdmScoreRankCompany(PdmScoreRankCompany pdmScoreRankCompany);

    /**
     * 修改单位积分排名
     *
     * @param pdmScoreRankCompany 单位积分排名
     * @return 结果
     */
    public int updatePdmScoreRankCompany(PdmScoreRankCompany pdmScoreRankCompany);

    /**
     * 删除单位积分排名
     *
     * @param id 单位积分排名主键
     * @return 结果
     */
    public int deletePdmScoreRankCompanyById(Long id);

    /**
     * 批量删除单位积分排名
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deletePdmScoreRankCompanyByIds(Long[] ids);
}
